@@ -11,6 +11,7 @@
 
 import sys
 import logging
+from termcolor import colored
 
 __all__ = ['get_logger', 'set_output_file', 'set_default_level',
            'log_dash', 'log_star', 'log_eq']
@@ -21,6 +22,26 @@ log_dash = lambda x: logging.debug(f"\n" + "-" * x + "\n")
 log_star = lambda x: logging.debug(f"\n" + "*" * x + "\n")
 log_eq = lambda x: logging.debug(f"\n" + "=" * x   + "\n")
 
+# ------------ Logging Utils ---------------- #
+# Print bold tex
+def bold(txt):
+    return colored(str(txt),attrs = ["bold"])
+
+# Print bold and colored text
+def bcolored(txt, color):
+    return colored(str(txt), color, attrs = ["bold"])
+
+# Write a line to file
+def writeline(f, line):
+    f.write(str(line) + "\n")
+
+# Write a list to file
+def writelist(f, l):
+    writeline(f, ",".join(map(str, l)))
+
+
+
+# ---------- LogFormatter ---------------- #
 class RSLogFormatter(logging.Formatter):
     def _color_err(self, msg):
         return '\x1b[1;4;31m{}\x1b[0m'.format(msg)
