@@ -15,14 +15,24 @@ import threading
 import contextlib
 
 from rsmlkit.collections.frozendict import frozendict
-from rsmlkit.logging import get_logger
+from rsmlkit.logging import get_logger, set_default_level, log_dash
 logger = get_logger(__file__)
 
-__all__ = ['decorator_with_optional_args',
+__all__ = ['trace',
+           'decorator_with_optional_args',
            'synchronized',
            'freezeargs',
            'timeit']
 
+def trace(func):
+    @functools.wraps(func)
+    def wrapped(*args, **kwargs):
+        log_dash(50)
+        logger.debug(f"[TRACE] func: {func.__name__}, args: {args}, kwargs: {kwargs}")
+        log_dash(50)
+        return func(*args, **kwargs)
+    return wrapped
+
 def timeit(func):
     """Log the runtime of the decorated function"""
     from timeit import default_timer as timer
